Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PgBatch ¶
type PgBatch struct {
Query func(ctx context.Context, q string, param ...any) *QueryResult
}
type QueryResult ¶
type QueryResult struct {
// contains filtered or unexported fields
}
func NewQueryResult ¶
func NewQueryResult(rows []map[string]any) *QueryResult
NewQueryResult creates a new QueryResult instance
func (*QueryResult) Get ¶
func (qr *QueryResult) Get(column string) (any, error)
Get retrieves the raw value of a column in the current row
func (*QueryResult) GetBool ¶
func (qr *QueryResult) GetBool(column string) (bool, error)
GetBool returns the column value as a boolean
func (*QueryResult) GetInt ¶
func (qr *QueryResult) GetInt(column string) (int, error)
GetInt returns the column value as an int (accepts int32, int64, float64)
func (*QueryResult) GetString ¶
func (qr *QueryResult) GetString(column string) (string, error)
GetString returns the column value as a string
func (*QueryResult) Next ¶
func (qr *QueryResult) Next() bool
Next moves the cursor to the next row,
Click to show internal directories.
Click to hide internal directories.